bmcmc
======
**An  MCMC package for Bayesian data analysis**

bmcmc is a general purpose mcmc package which should be 
useful for Bayesian data analysis. It
uses an adaptive scheme for automatic tuning of
proposal distributions. It can also handle
hierarchical Bayesian models via
Metropolis-Within-Gibbs scheme.


AUTHOR
-------
Sanjib Sharma  


Documentation
-------------
For latest documentation see here.
